WifiEvent

Enum WifiEvent 

#[non_exhaustive]
#[repr(i32)]
pub enum WifiEvent {
Show 45 variants WifiReady = 0, ScanDone = 1, StationStart = 2, StationStop = 3, StationConnected = 4, StationDisconnected = 5, StationAuthenticationModeChange = 6, StationWifiProtectedStatusEnrolleeSuccess = 7, StationWifiProtectedStatusEnrolleeFailed = 8, StationWifiProtectedStatusEnrolleeTimeout = 9, StationWifiProtectedStatusEnrolleePin = 10, StationWifiProtectedStatusEnrolleePushButtonConfigurationOverlap = 11, AccessPointStart = 12, AccessPointStop = 13, AccessPointStationConnected = 14, AccessPointStationDisconnected = 15, AccessPointProbeRequestReceived = 16, FineTimingMeasurementReport = 17, StationBasicServiceSetReceivedSignalStrengthIndicatorLow = 18, ActionTransmissionStatus = 19, RemainOnChannelDone = 20, StationBeaconTimeout = 21, ConnectionlessModuleWakeIntervalStart = 22, AccessPointWifiProtectedStatusRegistrarSuccess = 23, AccessPointWifiProtectedStatusRegistrarFailed = 24, AccessPointWifiProtectedStatusRegistrarTimeout = 25, AccessPointWifiProtectedStatusRegistrarPin = 26, AccessPointWifiProtectedStatusRegistrarPushButtonConfigurationOverlap = 27, IndividualTargetWakeTimeSetup = 28, IndividualTargetWakeTimeTeardown = 29, IndividualTargetWakeTimeProbe = 30, IndividualTargetWakeTimeSuspend = 31, TargetWakeTimeWakeup = 32, BroadcastTargetWakeTimeSetup = 33, BroadcastTargetWakeTimeTeardown = 34, NeighborAwarenessNetworkingStarted = 35, NeighborAwarenessNetworkingStopped = 36, NeighborAwarenessNetworkingServiceMatch = 37, NeighborAwarenessNetworkingReplied = 38, NeighborAwarenessNetworkingReceive = 39, NeighborDiscoveryProtocolIndication = 40, NeighborDiscoveryProtocolConfirmation = 41, NeighborDiscoveryProtocolTerminated = 42, HomeChannelChange = 43, StationNeighborRep = 44,
}
Available on crate feature unstable only.
Events generated by the Wi-Fi driver.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


WifiReady = 0

Wi-Fi is ready for operation.



ScanDone = 1

Scan operation has completed.



StationStart = 2

Station mode started.



StationStop = 3

Station mode stopped.



StationConnected = 4

Station connected to a network.



StationDisconnected = 5

Station disconnected from a network.



StationAuthenticationModeChange = 6

Station authentication mode changed.



StationWifiProtectedStatusEnrolleeSuccess = 7

Station Wi-Fi-Protected-Status succeeds in enrollee mode.



StationWifiProtectedStatusEnrolleeFailed = 8

Station Wi-Fi-Protected-Status fails in enrollee mode.



StationWifiProtectedStatusEnrolleeTimeout = 9

Station Wi-Fi-Protected-Status timeout in enrollee mode.



StationWifiProtectedStatusEnrolleePin = 10

Station Wi-Fi-Protected-Status pin code in enrollee mode.



StationWifiProtectedStatusEnrolleePushButtonConfigurationOverlap = 11

Station Wi-Fi-Protected-Status overlap in enrollee mode.



AccessPointStart = 12

Soft-AccessPoint start.



AccessPointStop = 13

Soft-AccessPoint stop.



AccessPointStationConnected = 14

A station connected to Soft-AccessPoint.



AccessPointStationDisconnected = 15

A station disconnected from Soft-AccessPoint.



AccessPointProbeRequestReceived = 16

Received probe request packet in Soft-AccessPoint interface.



FineTimingMeasurementReport = 17

Received report of Fine-Timing-Measurement procedure.



StationBasicServiceSetReceivedSignalStrengthIndicatorLow = 18

Station Receive-Signal-Strenght-Indicator goes below the configured threshold.



ActionTransmissionStatus = 19

Status indication of Action Transmission operation.



RemainOnChannelDone = 20

Remain-on-Channel operation complete.



StationBeaconTimeout = 21

Station beacon timeout.



ConnectionlessModuleWakeIntervalStart = 22

Connectionless module wake interval has started.



AccessPointWifiProtectedStatusRegistrarSuccess = 23

Soft-AccessPoint Wi-Fi-Protected-Status succeeded in registrar mode.



AccessPointWifiProtectedStatusRegistrarFailed = 24

Soft-AccessPoint Wi-Fi-Protected-Status failed in registrar mode.



AccessPointWifiProtectedStatusRegistrarTimeout = 25

Soft-AccessPoint Wi-Fi-Protected-Status timed out in registrar mode.



AccessPointWifiProtectedStatusRegistrarPin = 26

Soft-AccessPoint Wi-Fi-Protected-Status pin code in registrar mode.



AccessPointWifiProtectedStatusRegistrarPushButtonConfigurationOverlap = 27

Soft-AccessPoint Wi-Fi-Protected-Status overlap in registrar mode.



IndividualTargetWakeTimeSetup = 28

Individual Target-Wake-Time setup.



IndividualTargetWakeTimeTeardown = 29

Individual Target-Wake-Time teardown.



IndividualTargetWakeTimeProbe = 30

Individual Target-Wake-Time probe.



IndividualTargetWakeTimeSuspend = 31

Individual Target-Wake-Time suspended.



TargetWakeTimeWakeup = 32

Target-Wake-Wakeup event.



BroadcastTargetWakeTimeSetup = 33

Broadcast-Target-Wake-Time setup.



BroadcastTargetWakeTimeTeardown = 34

Broadcast-Target-Wake-Time teardown.



NeighborAwarenessNetworkingStarted = 35

Neighbor-Awareness-Networking discovery has started.



NeighborAwarenessNetworkingStopped = 36

Neighbor-Awareness-Networking discovery has stopped.



NeighborAwarenessNetworkingServiceMatch = 37

Neighbor-Awareness-Networking service discovery match found.



NeighborAwarenessNetworkingReplied = 38

Replied to a Neighbor-Awareness-Networking peer with service discovery match.



NeighborAwarenessNetworkingReceive = 39

Received a follow-up message in Neighbor-Awareness-Networking.



NeighborDiscoveryProtocolIndication = 40

Received NDP (Neighbor Discovery Protocol) request from a Neighbor-Awareness-Networking peer.



NeighborDiscoveryProtocolConfirmation = 41

NDP confirm indication.



NeighborDiscoveryProtocolTerminated = 42

Neighbor-Awareness-Networking datapath terminated indication.



HomeChannelChange = 43

Wi-Fi home channel change, doesn’t occur when scanning.



StationNeighborRep = 44

Received Neighbor Report response.