NeighborAwarenessNetworkingReceive

Struct NeighborAwarenessNetworkingReceive 

pub struct NeighborAwarenessNetworkingReceive<'a>(/* private fields */);
Available on crate feature unstable only.
See WifiEvent.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Implementations

Source

impl NeighborAwarenessNetworkingReceive<'_>

pub fn inst_id(&self) -> u8

Get Our Service Identifier.

pub fn peer_inst_id(&self) -> u8

Get Peer’s Service Identifier.

pub fn peer_if_mac(&self) -> &[u8; 6]

Get Peer’s NAN Interface MAC

pub fn peer_svc_info(&self) -> &[u8; 64]

Get Peer Service Info.